# Nasheq Bank Sync Standardized A.P.I.s Python Integrations

## Quick Guide
Below are the steps on how to get the web app up and running

1.	Install Dependencies:
```bash
    pip install requests
    pip install django-compression-middleware
    pip install djangorestframework
```
2.	Install Nash Sync ERP Library:
```bash
    pip install nashbanksync
```
3.	View get started documentation:
```bash
    https://nashbanksuite.readme.io/v1.2.0/docs
```
4.	Start Coding